@@ -1,11 +1,17 @@
 from python_graphql_client import GraphqlClient
 import numpy as np
-import re
 
 def splitIntoWords(str, badChars):
     return np.array(str.translate(str.maketrans( '', '', badChars)).split(" "))
 
+def validateBook(book):
+    strBook = str(book)
+    while len(strBook) < 3:
+        strBook = "0" + strBook
+    return strBook
+
 BAD_CHARS = "\""
+DEFAULT_MAX = 50
 
 class Entries:
     def __init__(self):
@@ -76,7 +82,7 @@ class Entries:
         except:
             print("No results found. Try running a query first.")
 
-    def associateInIndexes(self, words):
+    def associate(self, words):
         indexes = self.indexes()
         if indexes.any():
             containedStrs = [s["content"] for s in indexes for word in words if s["content"] is not None if word in s["content"]]
@@ -91,7 +97,7 @@ class Entries:
             print("Query resulted in error: ")
 
     # Query entries with no criteria.
-    def all(self, offset=0, max=50):
+    def all(self, offset=0, max=DEFAULT_MAX):
         query = """
             query ($max: Float!, $offset: Float!) {
                 entries(max: $max, offset: $offset) {
@@ -118,7 +124,7 @@ class Entries:
         return self;
 
     # Query entries that surround a specific date.
-    def withDate(self, date, max=50):
+    def withDate(self, date, max=DEFAULT_MAX):
         query = """
             query ($max: Float!, $date: DateInput!) {
                 entriesByDate(max: $max, date: $date) {
@@ -145,9 +151,9 @@ class Entries:
         return self;
 
     # Query entries that contain a specific keyword in their header/content.
-    def withKeyword(self, keyword, max=50):
+    def withKeyword(self, keyword, max=DEFAULT_MAX):
         query = """
-            query ($max: Float!, $keyword: String!) {
+            query ($max: Float!, $keyword: [String!]!) {
                 entriesByKeyword(max: $max, keyword: $keyword) {
                     book
                     header
@@ -167,14 +173,15 @@ class Entries:
                 }
             }
         """
-        variables = {"max": max,"keyword": str(keyword)}
+        variables = {"max": max,"keyword": keyword}
         self.query(query, variables, "entriesByKeyword")
         return self
 
+
     # Query entries with a specific volume of the diaries.
-    def withBook(self, book, max=50):
+    def withBook(self, book, max=DEFAULT_MAX):
         query = """
-            query ($max: Float!, $book: String!) {
+            query ($max: Float!, $book: [String!]!) {
                 entriesByBook(max: $max, book: $book) {
                     book
                     header
@@ -188,14 +195,18 @@ class Entries:
                     }
                     indexes {
                         book
-                        page
+                        pag
                         content
                     }
                 }
             }
         """
-        variables = {"max": max,"book": str(book)}
+        variables = {"max": max,"book": [validateBook(x) for x in book]}
         self.query(query, variables, "entriesByBook")
         return self
 
+    def withBookBetween(self, minBook, maxBook, max=DEFAULT_MAX):
+        return self.withBook([x for x in range(minBook, maxBook, 1)], max)
+
+
 
